@@ -9,11 +9,12 @@
 #' - `{tidygraph}` `tbl_graph` objects
 #' - `{network}` `network` objects
 #' @name coercion
-#' @param object A data frame edgelist, matrix, igraph, tidygraph, or network object.
-#' @param twomode An option to override the heuristics for distinguishing incidence
-#' from adjacency matrices. By default FALSE.
-#' @param weight An option to override the heuristics for distinguishing weighted
-#' networks. By default FALSE.
+#' @param object A data frame edgelist, matrix, igraph, tidygraph, or
+#' network object.
+#' @param twomode An option to override the heuristics for distinguishing
+#' incidence from adjacency matrices. By default FALSE.
+#' @param weight An option to override the heuristics for distinguishing
+#' weighted networks. By default FALSE.
 #' @details Behaviour is a little different depending on the data format.
 #' 
 #' If the data frame is a 2 column edgelist,
@@ -59,13 +60,14 @@ as_matrix.data.frame <- function(object, weight = FALSE){
         object <- as.data.frame(table(c(object[,1]),
                                       c(object[,2])))
       }
-      if (ncol(object) == 3) { # Adds a third (weight) column to a two-column edgelist
+      if (ncol(object) == 3) {
+        # Adds a third (weight) column to a two-column edgelist
         # object <- object[order(object[,1], object[,2]),]
         nodes1 <- as.character(unique(object[,1]))
         nodes1 <- sort(nodes1)
         nodes2 <- as.character(unique(object[,2]))
         nodes2 <- sort(nodes2)
-        if(nrow(object) != length(nodes1)*length(nodes2)){
+        if (nrow(object) != length(nodes1)*length(nodes2)) {
           allcombs <- expand.grid(object[,1:2], stringsAsFactors = FALSE)
           allcombs <- subset(allcombs, !duplicated(allcombs))
           object <- merge(allcombs, object, all.x = TRUE)
@@ -73,20 +75,21 @@ as_matrix.data.frame <- function(object, weight = FALSE){
           object[is.na(object)] <- 0
         }
         out <- structure(as.numeric(object[,3]),
-                         .Dim = c(as.integer(length(nodes1)), as.integer(length(nodes2))),
+                         .Dim = c(as.integer(length(nodes1)),
+                                  as.integer(length(nodes2))),
                          .Dimnames = list(nodes1, nodes2))
       }
   out
 }
 
 #' @export
-as_matrix.matrix <- function(object, weight = FALSE){
+as_matrix.matrix <- function(object, weight = FALSE) {
   object
 }
 
 #' @export
-as_matrix.igraph<- function(object, weight = FALSE){
-      if (is_twomode(object)){
+as_matrix.igraph <- function(object, weight = FALSE) {
+      if (is_twomode(object)) {
         mat <- igraph::as_incidence_matrix(object, sparse = FALSE)
       } else {
         mat <- igraph::as_adjacency_matrix(object, sparse = FALSE)
@@ -94,34 +97,36 @@ as_matrix.igraph<- function(object, weight = FALSE){
 }
 
 #' @export
-as_matrix.tbl_graph <- function(object, weight = FALSE){
+as_matrix.tbl_graph <- function(object, weight = FALSE) {
   as_matrix(as_igraph(object))
 }
 
 #' @export
-as_matrix.network <- function(object, weight = FALSE){
+as_matrix.network <- function(object, weight = FALSE) {
   network::as.matrix.network(object)
 }
 
 #' @rdname coercion
+#' @importFrom igraph graph_from_data_frame graph_from_incidence_matrix
+#' @importFrom igraph graph_from_adjacency_matrix
 #' @export
-as_igraph <- function(object, weight = FALSE, 
+as_igraph <- function(object,
+                      weight = FALSE,
                       twomode = FALSE) UseMethod("as_igraph")
 
 #' @export
-as_igraph.data.frame <- function(object, 
-                                 weight = FALSE, 
-                                 twomode = FALSE){
-  object <- as_matrix(object)
-  graph <- as_igraph(object)
+as_igraph.data.frame <- function(object,
+                                 weight = FALSE,
+                                 twomode = FALSE) {
+  graph <- igraph::graph_from_data_frame(object)
   graph
 }
 
 #' @export
-as_igraph.matrix <- function(object, 
-                             weight = FALSE, 
-                             twomode = FALSE){
-  if(nrow(object)!=ncol(object) | twomode){
+as_igraph.matrix <- function(object,
+                             weight = FALSE,
+                             twomode = FALSE) {
+  if (nrow(object) != ncol(object) | twomode) {
     graph <- igraph::graph_from_incidence_matrix(object)
   } else {
     graph <- igraph::graph_from_adjacency_matrix(object)
@@ -130,23 +135,25 @@ as_igraph.matrix <- function(object,
 }
 
 #' @export
-as_igraph.igraph <- function(object, weight = FALSE, 
-                             twomode = FALSE){
+as_igraph.igraph <- function(object,
+                             weight = FALSE,
+                             twomode = FALSE) {
   class(object) <- "igraph"
   object
 }
 
 #' @export
-as_igraph.tbl_graph <- function(object, weight = FALSE, 
-                                twomode = FALSE){
+as_igraph.tbl_graph <- function(object,
+                                weight = FALSE,
+                                twomode = FALSE) {
   class(object) <- "igraph"
   object
 }
 
 #' @export
 as_igraph.network <- function(object, weight = FALSE, 
-                                twomode = FALSE){
-  if(network::is.bipartite(object)){
+                                twomode = FALSE) {
+  if (network::is.bipartite(object)) {
     graph <- network::as.matrix.network.incidence(object)
     graph <- igraph::graph_from_incidence_matrix(graph)
   } else {
@@ -161,27 +168,27 @@ as_igraph.network <- function(object, weight = FALSE,
 as_tidygraph <- function(object, twomode = FALSE) UseMethod("as_tidygraph")
 
 #' @export
-as_tidygraph.data.frame <- function(object, twomode = FALSE){
+as_tidygraph.data.frame <- function(object, twomode = FALSE) {
   tidygraph::as_tbl_graph(as_igraph(object))
 }
 
 #' @export
-as_tidygraph.matrix <- function(object, twomode = FALSE){
+as_tidygraph.matrix <- function(object, twomode = FALSE) {
   tidygraph::as_tbl_graph(as_igraph(object))
 }
 
 #' @export
-as_tidygraph.igraph <- function(object, twomode = FALSE){
+as_tidygraph.igraph <- function(object, twomode = FALSE) {
   tidygraph::as_tbl_graph(object)
 }
 
 #' @export
-as_tidygraph.tbl_graph <- function(object, twomode = FALSE){
+as_tidygraph.tbl_graph <- function(object, twomode = FALSE) {
   object
 }
 
 #' @export
-as_tidygraph.network <- function(object, twomode = FALSE){
+as_tidygraph.network <- function(object, twomode = FALSE) {
   tidygraph::as_tbl_graph(as_igraph(object))
 }
 
@@ -190,14 +197,13 @@ as_tidygraph.network <- function(object, twomode = FALSE){
 as_network <- function(object) UseMethod("as_network")
 
 #' @export
-as_network.network <- function(object){
+as_network.network <- function(object) {
   object
 }
 
 #' @export
-as_network.matrix <- function(object){
-  
-  if(is_twomode(object)){
+as_network.matrix <- function(object) {
+  if (is_twomode(object)) {
     network::as.network(object, bipartite = TRUE)
   } else {
     network::as.network(object, bipartite = FALSE)
@@ -205,16 +211,16 @@ as_network.matrix <- function(object){
 }
 
 #' @export
-as_network.igraph <- function(object){
+as_network.igraph <- function(object) {
   as_network(as_matrix(object))
 }
 
 #' @export
-as_network.tbl_graph <- function(object){
+as_network.tbl_graph <- function(object) {
   as_network(as_matrix(object))
 }
 
 #' @export
-as_network.data.frame <- function(object){
+as_network.data.frame <- function(object) {
   as_network(as_matrix(object))
 }
