@@ -22,14 +22,22 @@ tidygraph::.N
 #' @export
 tidygraph::.E
 
+#' @importFrom tidygraph mutate
+#' @export
+tidygraph::mutate
+
+#' @importFrom tidygraph activate
+#' @export
+tidygraph::activate
+
 expect_nodes <- function() {
-  if (!.graph_context$free() && .graph_context$active() != 'nodes') {
-    stop('This call requires nodes to be active', call. = FALSE)
+  if (!.graph_context$free() && .graph_context$active() != "nodes") {
+    stop("This call requires nodes to be active", call. = FALSE)
   }
 }
 
 expect_edges <- function() {
-  if (!.graph_context$free() && .graph_context$active() != 'edges') {
-    stop('This call requires edges to be active', call. = FALSE)
+  if (!.graph_context$free() && .graph_context$active() != "edges") {
+    stop("This call requires edges to be active", call. = FALSE)
   }
 }
